# depynd
Evaluating dependencies among random variables.

## Dependencies
- Python (>=3.6)
- NumPy (>= 1.14.0)
- SciPy (>= 1.0.0)
- scikit-learn (>= 0.19.1)

## Installation
```
$ pip install depynd
```

